using System;
using System.IO;
using System.Collections.Generic;
using System.Text;

using OSGeo.FDO.Connections;
using OSGeo.FDO;
using OSGeo.FDO.Commands.Feature;
using OSGeo.FDO.ClientServices;

namespace ConsoleApplication1
{
    class Program
    {
        static void Main(string[] args)
        {

            string defaultDirectory = Environment.CurrentDirectory; 
            string className = "ILOT";

            // get the shp provider connection name
            string providerName = string.Empty;
            IProviderRegistry ipr = FeatureAccessManager.GetProviderRegistry();
            ProviderCollection pc = ipr.GetProviders();            
            foreach (Provider p in pc)
            {
                if (p.LibraryPath.ToLower() == "shpprovider.dll")
                {                    
                    providerName = p.Name;
                    break;
                }
            }
            Console.WriteLine("Opening " + providerName + " on " + defaultDirectory);
            // open the connection
            IConnectionManager connectionManager = FeatureAccessManager.GetConnectionManager();
            IConnection connection = connectionManager.CreateConnection(providerName);
            IConnectionPropertyDictionary connectionPropertyDictionary;
            connectionPropertyDictionary = connection.ConnectionInfo.ConnectionProperties;
            connectionPropertyDictionary.SetProperty("DefaultFileLocation", defaultDirectory);
            connectionPropertyDictionary.SetProperty("TemporaryFileLocation", defaultDirectory);
            ConnectionState connectState = connection.Open();
            if (connectState != ConnectionState.ConnectionState_Open) 
            {
                Console.WriteLine("Connection error");
                return;
            }
            // read all data from the class
            ISelect sel = (ISelect)connection.CreateCommand(OSGeo.FDO.Commands.CommandType.CommandType_Select);
            sel.SetFeatureClassName(className);
            IReader reader = sel.Execute();
            int count = 0;
            while (reader.ReadNext())
            {
                Console.WriteLine("FeatId #"+reader.GetInt32("FeatId"));
                count++;
            }
            reader.Close();
            Console.WriteLine("For a total of " + count + " features");
            // close and exit
            connection.Close();            
        }
    }
}
